==> eg_stop_unloading_my_shaders-v1.1.3-fabric-mc1.21.9-sources.jar: games/enchanted/eg_stop_unloading_my_shaders/common/ModConstants.java <==
package games.enchanted.eg_stop_unloading_my_shaders.common;

import games.enchanted.eg_stop_unloading_my_shaders.common.mixin.accessor.ShaderManagerAccessor;
//? if fabric {
import net.fabricmc.loader.api.FabricLoader;
//?} else {
/*import net.neoforged.fml.loading.FMLPaths;
*///?}
import net.minecraft.class_10151;
import net.minecraft.class_310;
import net.minecraft.class_3264;
import net.minecraft.class_3268;
import net.minecraft.class_3300;
import net.minecraft.class_3694;
import net.minecraft.class_6861;
import java.nio.file.Path;
import java.util.List;

public class ModConstants {
    public static final String MOD_NAME = "Stop Unloading My Shaders";
    public static final String MOD_ID = "eg_stop_unloading_my_shaders";

    public static final String TARGET_PLATFORM =
    //? if fabric {
        "fabric"
    //?} else {
        /*"neoforge"
     *///?}
    ;

    private static class_10151.class_10153 vanillaShaderConfigs;

    public static class_10151.class_10153 getVanillaShaderConfigs() {
        if(vanillaShaderConfigs != null) return vanillaShaderConfigs;

        class_3268 vanillaPack = class_310.method_1551().method_45573();
        class_3300 resourceManager = new class_6861(class_3264.field_14188, List.of(vanillaPack));
        vanillaShaderConfigs = ((ShaderManagerAccessor) class_310.method_1551().method_62887()).eg_sumr$invokePrepare(resourceManager, class_3694.field_16280);
        return vanillaShaderConfigs;
    }

    /**
     * Returns the path where configuration files are stored within the .minecraft directory
     */
    public static Path getConfigPath() {
        //? if fabric {
        return FabricLoader.getInstance().getConfigDir();
        //?} else {
        /*return FMLPaths.CONFIGDIR.get();
         *///?}
    }
}

==> eg_stop_unloading_my_shaders-v1.2.1-fabric-mc1.21.11-rc2-sources.jar: games/enchanted/eg_stop_unloading_my_shaders/common/ModConstants.java <==
package games.enchanted.eg_stop_unloading_my_shaders.common;

import games.enchanted.eg_stop_unloading_my_shaders.common.mixin.accessor.ShaderManagerAccessor;
//? if fabric {
import net.fabricmc.loader.api.FabricLoader;
//?} else {
/*import net.neoforged.fml.loading.FMLPaths;
*///?}
import net.minecraft.class_10151;
import net.minecraft.class_12289;
import net.minecraft.class_310;
import net.minecraft.class_3264;
import net.minecraft.class_3268;
import net.minecraft.class_3300;
import net.minecraft.class_3694;
import net.minecraft.class_6861;
import java.nio.file.Path;
import java.util.List;

public class ModConstants {
    public static final String MOD_NAME = "Stop Unloading My Shaders";
    public static final String MOD_ID = "eg_stop_unloading_my_shaders";

    public static final String TARGET_PLATFORM =
    //? if fabric {
        "fabric"
    //?} else {
        /*"neoforge"
     *///?}
    ;

    private static class_10151.class_10153 vanillaShaderConfigs;

    public static class_10151.class_10153 getVanillaShaderConfigs() {
        if(vanillaShaderConfigs != null) return vanillaShaderConfigs;

        class_3268 vanillaPack = class_310.method_1551().method_45573();
        class_3300 resourceManager = new class_6861(class_3264.field_14188, List.of(vanillaPack));
        vanillaShaderConfigs = ((ShaderManagerAccessor) class_310.method_1551().method_62887()).eg_sumr$invokePrepare(resourceManager, class_3694.field_16280);
        return vanillaShaderConfigs;
    }

    public static class_12289 getVanillaShaderSource() {
        class_10151.class_10153 configs = getVanillaShaderConfigs();
        return (identifier, shaderType) -> configs.comp_3106().get(new class_10151.class_10155(identifier, shaderType));
    }

    /**
     * Returns the path where configuration files are stored within the .minecraft directory
     */
    public static Path getConfigPath() {
        //? if fabric {
        return FabricLoader.getInstance().getConfigDir();
        //?} else {
        /*return FMLPaths.CONFIGDIR.get();
         *///?}
    }
}
